#!/bin/sh
#
# Written by Geoff Mottram (geoff at minaret dot biz).
#
# Placed in the public domain by the author.
#
# See LICENSE.txt for NO WARRANTY statement.
#

#
# Copies the root file system from a running IX2
# with a host hame of "ix2" to ../.. minus any
# mounted file systems, system logs or root's
# home directory.
#

SOURCE="root@ix2:/"
TARGET=`readlink -f ../..`

# check the current directory
if [ ! -d ../dts ]; then
    cat <<END

You appear to be in the wrong directory.
Cannot locate "../dts" directory.
You must run this script from the "boot/tools" directory.

END
    exit 1
fi

clear
cat << END
This script will clone the files in a running IX2 device to
a local directory. No mounted file systems will be copied
and neither will any of the following:

    /images
    /lost+found
    /root
    /var/log
    /etc/ssh/ssh_host_*

This script is used to update a "clean" version of the 
IX2 root file system in preparation for installing the
Debian O/S on a target device. The target directory
should have an existing Debian root file system because
not all files are copied from the source (IX2) system.

SOURCE: $SOURCE
TARGET: $TARGET

END
echo -n "Press any key to continue or CTRL-C to quit: "
read ANS
if [ ! -d "$TARGET" ]; then
    echo
    echo "TARGET directory does not exist: $TARGET"
    exit 1
fi

#
# rsync options used:
#   -a  archive (preserves owner, mod time, etc.)
#   -v  verbose
#   -x  skip mounted file systems (/sys, /proc, /mnt, etc.)
#   
# Call this script with -n for a dry run.
#
if rsync -avx $@ --delete --inplace $SOURCE $TARGET --exclude /images --exclude /lost+found --exclude /root --exclude /var/log --exclude '/etc/ssh/ssh_host_*'; then
    echo "\nSuccessful copy"
else
    echo "\nError: rsync returned $?"
    exit 1
fi
