#!/bin/sh
#
# Written by Geoff Mottram (geoff at minaret dot biz).
#
# Placed in the public domain by the author.
#
# See LICENSE.txt for NO WARRANTY statement.
#

#
# Customization script that installs original Bohdi root
# file system files. It copies all of the files in this
# directory (except the script itself) to the destination.
#

# 
# Minimally, the following environment variables will be
# set by the install.sh script:
#
#    TARGET_DEVICE: "sdX"
#     INSTALL_TYPE: "usb" or "ide"
#      DEVICE_TYPE: "all" or shortened DTS name
#        SWAP_SIZE: 256, 512, 768 or 1024 (MiB)
#        ROOT_SIZE: -1=all, or 2-512 (GiB)
#           FSTYPE: "ext2", "ext3" or "ext4"
#        CUSTOMIZE: "orig" or "ix2"
#
# The full path to the target root directory (without a
# trailing slash will be passed in TARGET_ROOT.
#
# The current directory will be this directory.
#

# Make sure environment variables are set
if [ -z "$TARGET_ROOT" ]; then
	echo "$0: Environment variable \"TARGET_ROOT\" is not set"
	exit 1
fi

cat <<END

$0: Installing original files
From: boot/tools/custom/orig
  To: $TARGET_ROOT

END

#
# Copy all regular files except this script.
# -p pass-through
# -d create directories
# -m preserve modification time
# -u unconditional
# -v verbose
#
find . -type f | grep -v "install.sh" | cpio -pdmuv "$TARGET_ROOT"
